comm: Jupyter Python Comm implementation, for usage in ipykernel, xeus-python etc.
==================================================================================

Description
-----------

Jupyter Python Comm implementation, for usage in ipykernel, xeus-python etc.

License
-------

BSD 3-Clause License

Upstream Contact
----------------

https://pypi.org/project/comm/

